@@ -13,7 +13,10 @@ from vim_quest_cli.interface.curses_window import Window
 from vim_quest_cli.interface.terminal_ui import TerminalUI
 from vim_quest_cli.mode.go_to_x import GoToXMode
 from vim_quest_cli.mode.labyrinth import LabyrinthMode
+from vim_quest_cli.mode.mode_container import ModeContainer
 from vim_quest_cli.mode.mode_interface import Mode
+from vim_quest_cli.mode.search_x_and_destroy import SearchXAndDestroy
+from vim_quest_cli.mode.welcome import WelcomeScreen
 from vim_quest_cli.view.view import ViewFactory
 
 
@@ -24,14 +27,17 @@ class Engines(enum.Enum):
 
 
 class Modes(enum.Enum):
-    GOT_TO_X = GoToXMode
-    LABYRINTH = LabyrinthMode
+    GOT_TO_X: Mode = GoToXMode
+    LABYRINTH: Mode = LabyrinthMode
+    SEARCH_X_AND_DESTROY: Mode = SearchXAndDestroy
+    DEFAULT: Mode = SearchXAndDestroy
 
 
 @dataclasses.dataclass(frozen=True)
 class Options:
     engine_cls: EngineInterface
     terminal: str
+    mode_cls: Mode
 
 
 def parse_args() -> Options:
@@ -51,13 +57,20 @@ def parse_args() -> Options:
         choices=("ansi", "curses"),
         help="wich terminal to use",
     )
-    # TODO add param for the mode
-    # TODO add param for a file to load
+    parser.add_argument(
+        "-m",
+        "--mode",
+        default=Modes.DEFAULT.value,
+        type=lambda v: Modes[v].value,
+        choices=[e.name for e in Modes],
+        help="select the mode to use",
+    )
 
     parsed_args = parser.parse_args()
     return Options(
         engine_cls=parsed_args.engine,
         terminal=parsed_args.terminal,
+        mode_cls=parsed_args.mode,
     )
 
 
@@ -68,12 +81,11 @@ def main():
         buffer="tu to\nto#to\nti#ti\ntu#tu\nti tu".split("\n"),
     )
 
-    mode_cls = Modes.GOT_TO_X.value
-
-    mode = mode_cls(
+    mode = ModeContainer(
         engine=args.engine_cls(),
         view=ViewFactory(),
         state=state,
+        mode_fct_list=[WelcomeScreen, GoToXMode, SearchXAndDestroy],
     )
 
     t = TerminalUI(mode=mode)
@@ -87,16 +99,18 @@ def main():
 
 
 def as_single_method():
-    t = TerminalUI(
-        mode=Modes.GOT_TO_X.value(
-            engine=PurePythonEngine(),
-            view=ViewFactory(),
-            state=EngineState(
-                buffer="tu to\nto#to\nti#ti\ntu#tu\nti tu".split("\n"),
-            ),
+
+    mode = ModeContainer(
+        engine=PurePythonEngine(),
+        view=ViewFactory(),
+        state=EngineState(
+            buffer="tu to\nto#to\nti#ti\ntu#tu\nti tu".split("\n"),
         ),
+        mode_fct_list=[WelcomeScreen, GoToXMode, SearchXAndDestroy],
     )
 
+    t = TerminalUI(mode=mode)
+
     def res_method(user_input: str) -> str:
         res = []
         w = Window(stdout_write_fct=res.append)
