@@ -5,9 +5,11 @@ Curbatitur sapien neque
 id nisl. Fusce id diam id
 -
 vitae mi non orci ultricies
-""".split("\n")
+""".split(
+    "\n"
+)
 
-BLOCK_TEXT = """
+BLOCK_TEXT = r"""
  <- Cursor, move with 'j' 🧱.
                           🧱.
                           🧱.
@@ -36,4 +38,8 @@ Blocked ?. Try 'l'          .
     🧱   |     🧱           .
     🧱   k     🧱           .
                🧱  goal->  🍩.
-""".split('\n')[1:-1]
+""".split(
+    "\n"
+)[
+    1:-1
+]
