@@ -2,7 +2,12 @@
 import dataclasses
 import enum
 import itertools
-from typing import List
+from typing import List, Iterable, Union, Tuple
+
+from vim_quest_cli.interface.mapping import Keys
+
+
+# TODO put EVERYTHING in base 0. Because otherwise it's too complex to understand.
 
 
 @dataclasses.dataclass(frozen=True)
@@ -18,7 +23,7 @@ class CursorPos:
 DEFAULT_CURSOR_POS = CursorPos()
 
 
-@dataclasses.dataclass(frozen=True)
+@dataclasses.dataclass(frozen=True, eq=True)
 class EngineState:
     cursor: CursorPos = DEFAULT_CURSOR_POS
 
@@ -28,11 +33,11 @@ class EngineState:
     # screen_xpos: int = 0
     # screen_ypos: int = 0
 
-    buffer: List[str] = dataclasses.field(default_factory=list)
+    buffer: Tuple[str] = dataclasses.field(default_factory=tuple)
     # paste: str = ""
     # command: str = ""
     # search: str = ""
-    command: List[str] = dataclasses.field(default_factory=list)
+    command: Tuple[Union[Keys, str]] = dataclasses.field(default_factory=tuple)
 
     # should_quit: bool = False
 
