@@ -50,7 +50,7 @@ class TerminalUI:
             self._refresh_state(view, stdscr)
             return
 
-        if 'q' in input_keys:
+        if "q" in input_keys:
             raise StopIteration()
 
         view = self._mode.feedkeys(input_keys)
