@@ -4,14 +4,32 @@ from typing import Iterable
 
 from vim_quest_cli.engine.engine_interface import EngineInterface, EngineState
 from vim_quest_cli.interface.mapping import Keys
-from vim_quest_cli.view.view import ViewFactory, ViewData
+from vim_quest_cli.view.view import ViewFactory, ViewData, CharacterView
+
+
+class ModeHelper:
+    @staticmethod
+    def char_under_cursor(state: EngineState):
+        return state.buffer[state.cursor.line - 1][state.cursor.col - 1]
+
+    @staticmethod
+    def set_view_char_raw(view: ViewData, char: str, line: int, column: int):
+        """Change a single character in the view. Throw exception if out of bound."""
+        view.chars[line - 1][column - 1] = CharacterView(ascii=char)
+
+    @staticmethod
+    def set_view_char(view: ViewData, char: str, line: int, column: int):
+        """Change a single character in the view. Ignore out of bounds."""
+        # TODO: make sure the cursor and the line/col are on the same base.
+        # I think it's going to be easier to be all 0 based from now on, and to adapt the interface to be otherwise.
+        if line < 1 or line > len(view.chars):
+            return
+        if column < 1 or column > len(view.chars[0]):
+            return
+        view.chars[line - 1][column - 1] = CharacterView(ascii=char)
 
 
 class Mode:
-    engine: EngineInterface
-    state: EngineState
-    view: ViewFactory
-
     def __init__(self, engine: EngineInterface, state: EngineState, view: ViewFactory):
         self._engine = engine
         self._state = state
@@ -29,8 +47,9 @@ class Mode:
         return self.change_view(view)
 
     # To be overloaded by subclasses
+
     def _init_after_params(self):
-        pass
+        ...
 
     def change_view(self, view: ViewData) -> ViewData:
         return view
@@ -40,6 +59,14 @@ class Mode:
     ) -> EngineState:
         return state_end
 
+    # Easy way to copy modes.
+    def kwargs_create_mode(self):
+        return dict(
+            engine=self._engine,
+            state=self._state,
+            view=self._view,
+        )
+
 
 """
 
